@@ -9,14 +9,14 @@ use lib map { "$ENV{HOME}/sandbox/$_/lib" } qw(Synth-Config);
 use Synth::Config ();
 
 get '/' => sub ($c) {
-  my $model = $c->param('model');
-  my $name = $c->param('name');
-  my $group = $c->param('group');
+  my $model  = $c->param('model');
+  my $name   = $c->param('name');
+  my $group  = $c->param('group');
   my $fields = $c->param('fields');
   my ($models, $names, $groups, $settings);
-  $model = trim($model);
-  $name = trim($name);
-  $fields = trim($fields);
+  $model  = trim($model)  if $model;
+  $name   = trim($name)   if $name;
+  $fields = trim($fields) if $fields;
   my $synth = Synth::Config->new(model => $model, verbose => 1);
   if ($model) {
     # get a specs config file for the synth model
@@ -30,10 +30,12 @@ get '/' => sub ($c) {
       my %parameters;
       $parameters{group} = $group if $group;
       $parameters{name}  = $name  if $name;
-      my @fields = split /\s*,\s*/, $fields;
-      for my $f (@fields) {
-        my ($x, $y) = split /\s*:\s*/, $f;
-        $parameters{$x} = $y;
+      if ($fields) {
+        my @fields = split /\s*,\s*/, $fields;
+        for my $f (@fields) {
+          my ($x, $y) = split /\s*:\s*/, $f;
+          $parameters{$x} = $y;
+        }
       }
       $settings = $synth->search_settings(%parameters);
     }
@@ -83,8 +85,8 @@ get '/edit' => sub ($c) {
   my $value      = $c->param('value');
   my $unit       = $c->param('unit');
   my $is_default = $c->param('is_default');
-  $model = trim $model;
-  $name = trim $name;
+  $model = trim($model) if $model;
+  $name = trim($name) if $name;
   my $synth = Synth::Config->new(model => $model);
   # get a specs config file for the synth model
   my $set = './eg/' . $synth->model . '.set';
@@ -134,9 +136,9 @@ post '/update' => sub ($c) {
     $c->flash(error => 'Could not update');
     return $c->redirect_to('edit');
   }
-  my $model = trim $v->param('model');
-  my $name = trim $v->param('name');
-  my $value = trim $v->param('value');
+  my $model = trim $v->param('model') if $v->param('model');
+  my $name  = trim $v->param('name')  if $v->param('name');
+  my $value = trim $v->param('value') if $v->param('value');
   my $synth = Synth::Config->new(model => $model);
   # get a specs config file for the synth model
   my $set = './eg/' . $synth->model . '.set';
@@ -190,25 +192,22 @@ __DATA__
 <form action="<%= url_for('index') %>" method="get">
 <div class="row">
   <div class="col">
-    <label for="model" class="form-label">Model:</label>
     <select name="model" id="model" class="form-select" required>
-      <option value="">Model...</option>
+      <option value="">Model name...</option>
 % for my $m (@$models) {
       <option value="<%= $m %>" <%= $models && lc($m) eq lc($model) ? 'selected' : '' %>><%= ucfirst $m %></option>
 % }
     </select>
   </div>
   <div class="col">
-    <label for="name" class="form-label">Name:</label>
     <select name="name" id="name" class="form-select">
-      <option value="">Name...</option>
+      <option value="">Setting name...</option>
 % for my $n (@$names) {
       <option value="<%= $n %>" <%= $names && $n eq $name ? 'selected' : '' %>><%= ucfirst $n %></option>
 % }
     </select>
   </div>
   <div class="col">
-    <label for="group" class="form-label">Group:</label>
     <select name="group" id="group" class="form-select">
       <option value="">Group...</option>
 % for my $g (@$groups) {
@@ -220,7 +219,6 @@ __DATA__
 <p></p>
 <div class="row">
   <div class="col">
-    <label for="fields" class="form-label">Search fields:</label>
     <input type="text" name="fields" id="fields" value="<%= $fields %>" class="form-control" placeholder="field1:value1, field2:value2, etc.">
   </div>
 </div>
@@ -275,10 +273,10 @@ __DATA__
   <input type="hidden" name="id" value="<%= $id %>">
 <div class="row">
   <div class="col">
-    <input type="text" name="model" id="model" value="<%= ucfirst $model %>" class="form-control" required>
+    <input type="text" name="model" id="model" value="<%= ucfirst $model %>" class="form-control" placeholder="Model name" required>
   </div>
   <div class="col">
-    <input type="text" name="name" id="name" value="<%= $name %>" class="form-control" required>
+    <input type="text" name="name" id="name" value="<%= $name %>" class="form-control" placeholder="Setting name" required>
   </div>
 </div>
 <p></p>
@@ -294,7 +292,7 @@ __DATA__
   <div class="col">
 %   }
 %   if ($key eq 'value') {
-    <input type="text" name="<%= $key %>" id="<%= $key %>" value="<%= $selected->{value} %>" class="form-control">
+    <input type="text" name="<%= $key %>" id="<%= $key %>" value="<%= $selected->{value} %>" class="form-control" placeholder="Setting value">
 %   } elsif ($key eq 'is_default') {
     Is default: &nbsp;
     <div class="form-check form-check-inline">
